@@ -5,6 +5,7 @@ use serde::{Deserialize, Serialize};
 #[serde(default)]
 pub struct HostnameConfig<'a> {
     pub ssh_only: bool,
+    pub ssh_symbol: &'a str,
     pub trim_at: &'a str,
     pub format: &'a str,
     pub style: &'a str,
@@ -15,8 +16,9 @@ impl<'a> Default for HostnameConfig<'a> {
     fn default() -> Self {
         HostnameConfig {
             ssh_only: true,
+            ssh_symbol: "🌐 ",
             trim_at: ".",
-            format: "[$hostname]($style) in ",
+            format: "[$ssh_symbol$hostname]($style) in ",
             style: "green dimmed bold",
             disabled: false,
         }
