@@ -17,6 +17,8 @@ pub struct StatusConfig<'a> {
     pub pipestatus: bool,
     pub pipestatus_separator: &'a str,
     pub pipestatus_format: &'a str,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub pipestatus_segment_format: Option<&'a str>,
     pub disabled: bool,
 }
 
@@ -37,6 +39,7 @@ impl<'a> Default for StatusConfig<'a> {
             pipestatus_separator: "|",
             pipestatus_format:
                 "\\[$pipestatus\\] => [$symbol$common_meaning$signal_name$maybe_int]($style)",
+            pipestatus_segment_format: None,
             disabled: true,
         }
     }
